@@ -1,5 +1,5 @@
-from src.OOTUI.Window import Window
-from src.OOTUI.Vector2 import Vector2
+from .Window import Window
+from .Vector2 import Vector2
 import os
 
 
